clear all
close all
clc
%% Initializaton of the problem
vars = load('ipopt-repeatability-issue.mat');
Xi = vars.Xi;
Tt = vars.Tt;
ub = vars.ub;
lb = vars.lb;
Xf_fmincon = zeros(size(Xi));
Xf_ipopt = zeros(size(Xi));
%% Options for the solver
real_eps = 1.2e-7;
tolX = 4*real_eps;
tolP = 4*real_eps;
MaxIter = 1500; % VUD
% - Ipopt
options_ipopt = struct();
options_ipopt.lb = lb;
options_ipopt.ub = ub;
options_ipopt.ipopt.mu_strategy = 'monotone';
options_ipopt.ipopt.print_level = 0;
options_ipopt.ipopt.max_iter = MaxIter;
options_ipopt.ipopt.tol = tolX;
options_ipopt.ipopt.hessian_approximation = 'limited-memory';
options_ipopt.ipopt.limited_memory_max_history = 10;
options_ipopt.ipopt.linear_solver = 'ma57';
options_ipopt.ipopt.ma57_pivtol = 0.01;
% - fmincon
options_fmincon = optimset('Algorithm','interior-point','Display','none','MaxIter',MaxIter,'MaxFunEvals',10*MaxIter,'tolX',tolX,'TolFun',tolP,'GradObj','on','Hessian','lbfgs');
%% Computation of the solutions
for i = 1:size(Xi,1)
    % Ipopt
    funcs.objective = @(x)objective(x,Tt);
    funcs.gradient = @(x)gradient(x,Tt);
    [Xf_ipopt(i,:),info] = ipopt(Xi(i,:),funcs,options_ipopt);
    % fmincon
    Xf_fmincon(i,:) = fmincon(@(x)objective_gradient(x,Tt),Xi(i,:),[],[],[],[],lb,ub,[],options_fmincon);
end
%% Some display
fprintf(['\n----------------------------------------------------------' ...
         '\n                       STATISTICS                         ' ...
         '\n----------------------------------------------------------']);
fprintf(['\n                    Results average                       ' ...
         '\n----------------------------------------------------------\n']');
fprintf('fmincon: %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f\n', mean(Xf_fmincon,1));
fprintf('  Ipopt: %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f\n', mean(Xf_ipopt,1));
fprintf(['----------------------------------------------------------' ...
         '\n                 Results standard deviation               ' ...
         '\n----------------------------------------------------------\n']');
fprintf('fmincon: %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f\n', std(Xf_fmincon,[],1));
fprintf('  Ipopt: %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f    %0.4f\n', std(Xf_ipopt,[],1));
fprintf('\n');